@@ -4,7 +4,8 @@ use strict;
 use warnings;
 
 use Catalyst::Runtime '5.70';
-use Catalyst qw/ConfigLoader Static::Simple/;
+use Catalyst;
+
 our $VERSION = '0.01';
 __PACKAGE__->config( name => 'PostApp' );
 __PACKAGE__->setup;
